LocationProximity class

A class that represents a location around which places will be searched.

Implemented types

Constructors

LocationProximity({required Location loc})
const

Properties

asString → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
loc → Location
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited