Suggestion class

Annotations
  • @JsonSerializable.new()

Constructors

Suggestion({required String name, String? namePreferred, required String mapboxId, required String featureType, required String? address, required String? fullAddress, required String placeFormatted, required Context? context, required String language, required String? maki, ExternalIds? externalIds, List<String>? poiCategory, List<String>? poiCategoryIds, List<String>? brand, List<String>? brandId})
Suggestion.fromJson(Map<String, dynamic> json)
factory

Properties

address → String?
final
brand → List<String>?
final
brandId → List<String>?
final
context → Context?
final
externalIds → ExternalIds?
final
featureType → String
final
fullAddress → String?
final
hashCode → int
The hash code for this object.
no setterinherited
language → String
final
maki → String?
final
mapboxId → String
final
name → String
final
namePreferred → String?
final
placeFormatted → String
final
poiCategory → List<String>?
final
poiCategoryIds → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited